@@ -418,6 +418,18 @@ class HierarchicalRequirement(BaseRallyModel):
 
         return cls.get_all([clauses])
 
+    @classmethod
+    def get_all_in_iteration(cls, iteration_name):
+        clauses = ['Iteration.Name = "{0}"'.format(iteration_name)]
+        return cls.get_all(clauses)
+
+    def get_rally_url(self):
+        story_id = self.ref.split('/')[-1].replace('.js', '')
+        base_url = get_accessor().base_url
+        url = "{0}slm/rally.sp#/detail/userstory/{1}".format(base_url,
+                                                             story_id)
+        return url
+
 
 class Defect(BaseRallyModel):
     rally_name = "Defect"
@@ -440,6 +452,13 @@ class Defect(BaseRallyModel):
 
         return cls.get_all([clauses])
 
+    def get_rally_url(self):
+        defect_id = self.ref.split('/')[-1].replace('.js', '')
+        base_url = get_accessor().base_url
+        url = "{0}slm/rally.sp#/defect/userstory/{1}".format(base_url,
+                                                             defect_id)
+        return url
+
 
 class User(BaseRallyModel):
     rally_name = 'User'
